@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "pass-coffin" "1.0.0"
+(define-package "pass-coffin" "20251231.1407"
   "Interface to \"pass coffin\"."
   '((emacs "28.1"))
   :url "https://codeberg.org/rch/emacs-pass-coffin"
